@@ -33,14 +33,7 @@ namespace priv
       {
       arma_ignore(junk);
       
-      if(std::numeric_limits<eT>::has_quiet_NaN)
-        {
-        return std::numeric_limits<eT>::quiet_NaN();
-        }
-      else
-        {
-        return eT(0);
-        }
+      return (std::numeric_limits<eT>::has_quiet_NaN) ? eT(std::numeric_limits<eT>::quiet_NaN()) : eT(0);
       }
     
     
@@ -75,14 +68,7 @@ namespace priv
       {
       arma_ignore(junk);
       
-      if(std::numeric_limits<eT>::has_infinity)
-        {
-        return std::numeric_limits<eT>::infinity();
-        }
-      else
-        {
-        return std::numeric_limits<eT>::max();
-        }
+      return (std::numeric_limits<eT>::has_infinity) ? eT(std::numeric_limits<eT>::infinity()) : eT(std::numeric_limits<eT>::max());
       }
     
     
@@ -98,7 +84,7 @@ namespace priv
       return eT( Datum_helper::inf<T>(), Datum_helper::inf<T>() );
       }
     
-
+    
     template<typename eT>
     static
     typename arma_integral_only<eT>::result
@@ -108,7 +94,6 @@ namespace priv
       
       return std::numeric_limits<eT>::max();
       }
-    
     };
   }
 
@@ -127,6 +112,7 @@ class Datum
   public:
   
   static const eT pi;           //!< ratio of any circle's circumference to its diameter
+  static const eT tau;          //!< ratio of any circle's circumference to its radius (replacement of 2*pi)
   static const eT e;            //!< base of the natural logarithm
   static const eT euler;        //!< Euler's constant, aka Euler-Mascheroni constant
   static const eT gratio;       //!< golden ratio
@@ -177,6 +163,7 @@ class Datum
 // and any smart compiler that does high-precision computation at compile-time
   
 template<typename eT> const eT Datum<eT>::pi          = eT(3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679);
+template<typename eT> const eT Datum<eT>::tau         = eT(6.2831853071795864769252867665590057683943387987502116419498891846156328125724179972560696506842341359);
 template<typename eT> const eT Datum<eT>::e           = eT(2.7182818284590452353602874713526624977572470936999595749669676277240766303535475945713821785251664274);
 template<typename eT> const eT Datum<eT>::euler       = eT(0.5772156649015328606065120900824024310421593359399235988057672348848677267776646709369470632917467495);
 template<typename eT> const eT Datum<eT>::gratio      = eT(1.6180339887498948482045868343656381177203091798057628621354486227052604628189024497072072041893911374);
@@ -221,8 +208,8 @@ template<typename eT> const eT Datum<eT>::b         = eT(2.897771955e-3);
 
 
 
-typedef Datum<float>  fdatum;
-typedef Datum<double> datum;
+typedef Datum<float >  fdatum;
+typedef Datum<double>   datum;
 
 
 
